aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/calendar-component.c
diff options
context:
space:
mode:
Diffstat (limited to 'calendar/gui/calendar-component.c')
-rw-r--r--calendar/gui/calendar-component.c24
1 files changed, 2 insertions, 22 deletions
diff --git a/calendar/gui/calendar-component.c b/calendar/gui/calendar-component.c
index 74852b18a3..857812f5c3 100644
--- a/calendar/gui/calendar-component.c
+++ b/calendar/gui/calendar-component.c
@@ -571,12 +571,6 @@ config_primary_selection_changed_cb (GConfClient *client, guint id, GConfEntry *
}
static void
-config_calendars_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
-{
- update_selection (data);
-}
-
-static void
config_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
{
update_task_selection (data);
@@ -584,12 +578,6 @@ config_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *en
static void
-config_primary_calendar_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
-{
- update_primary_selection (data);
-}
-
-static void
config_primary_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
{
update_primary_task_selection (data);
@@ -1126,16 +1114,8 @@ create_component_view (CalendarComponent *calendar_component)
update_task_selection (component_view);
update_primary_task_selection (component_view);
- /* If the calendar selection changes elsewhere, update it */
- not = calendar_config_add_notification_calendars_selected (config_calendars_selection_changed_cb,
- component_view);
- component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));
-
- not = calendar_config_add_notification_primary_calendar (config_primary_calendar_selection_changed_cb,
- component_view);
- component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));
-
- /* If the task selection changes elsewhere, update it */
+ /* If the tasks selection changes elsewhere, update it for the mini
+ mini tasks view sidebar */
not = calendar_config_add_notification_tasks_selected (config_tasks_selection_changed_cb,
component_view);
component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));